==> mobile_pos-0.8.12.tar.gz: lib/src/views/network_stability/network_stability.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/network_stability/network_status_sheet.dart';

class NetworkStability extends StatefulWidget {
  const NetworkStability({super.key});

  @override
  State<NetworkStability> createState() => _NetworkStabilityState();
}

class _NetworkStabilityState extends State<NetworkStability> {
  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        showLogo: true,
        body: Padding(
            padding: EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
            child:
                Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
              const Gap(24),
              Row(
                children: [
                  RavenPayCloseButton(
                    isArrow: true,
                    text: "",
                    onBackPressed: () {
                      Navigator.pop(context);
                    },
                  ),
                ],
              ),
              const Gap(24),
              Text("Network Settings", style: headling1),
              const Gap(4),
              Text("This is the network settings attached to your",
                  style: subtitle2.copyWith(fontSize: 14)),
              const Gap(20),
              Container(
                  padding:
                      const EdgeInsets.symmetric(horizontal: 12, vertical: 16),
                  decoration: BoxDecoration(
                      boxShadow: const [
                        BoxShadow(
                            color: Color(0xFFEFEFEF),
                            spreadRadius: 2,
                            blurRadius: 16)
                      ],
                      color: Colors.white,
                      borderRadius: BorderRadius.circular(12)),
                  child: const Column(
                    children: [
                      ItemView(
                        title: "Super Fast ⚡️",
                        subText: "N15 per transaction on BankBox",
                      ),
                      Divider(
                        height: 20,
                      ),
                      ItemView(
                        title: "Fast",
                        subText: "N20 per transaction on BankBox",
                      ),
                    ],
                  )),
              const Gap(32),
              GestureDetector(
                onTap: () {
                  showRavenPayBottomSheet(context,
                      child: const NetworkStatusSheet());
                },
                child: Container(
                    padding: const EdgeInsets.symmetric(
                        horizontal: 16, vertical: 20),
                    decoration: BoxDecoration(
                        boxShadow: const [
                          BoxShadow(
                              color: Color(0xFFEFEFEF),
                              spreadRadius: 2,
                              blurRadius: 16)
                        ],
                        color: Colors.white,
                        borderRadius: BorderRadius.circular(12)),
                    child: Row(
                      children: [
                        Image.asset(loadAsset("network_stability.png"),
                            color: pluginConfig.theme!.primaryColor,
                            height: 20),
                        const Gap(12),
                        Expanded(
                          child: Text(
                            "View Network Status",
                            style: subtitle.copyWith(
                                color: pluginConfig.theme!.primaryColor),
                          ),
                        ),
                        const Icon(Icons.arrow_forward_ios, size: 12)
                      ],
                    )),
              )
            ])));
  }
}

class ItemView extends StatelessWidget {
  final String title;
  final String subText;
  const ItemView({super.key, required this.title, required this.subText});

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        SizedBox(
            width: 24,
            child: Radio(
                fillColor:
                    MaterialStateProperty.all(Colors.grey.withOpacity(0.4)),
                value: 1,
                groupValue: 0,
                onChanged: (val) {})),
        const Gap(8),
        Expanded(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(title, style: headling1.copyWith(fontSize: 16)),
              const Gap(2),
              Text(
                subText,
                style: subtitle2.copyWith(fontSize: 14),
              )
            ],
          ),
        )
      ],
    );
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/src/views/network_stability/network_stability.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/network_stability/network_status_sheet.dart';

class NetworkStability extends StatefulWidget {
  const NetworkStability({super.key});

  @override
  State<NetworkStability> createState() => _NetworkStabilityState();
}

class _NetworkStabilityState extends State<NetworkStability> {
  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        showLogo: true,
        body: Padding(
            padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
            child:
                Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
              const Gap(24),
              Row(
                children: [
                  RavenPayCloseButton(
                    isArrow: true,
                    text: "",
                    onBackPressed: () {
                      Navigator.pop(context);
                    },
                  ),
                ],
              ),
              const Gap(24),
              Text("Network Settings", style: headling1),
              const Gap(4),
              Text("This is the network settings attached to your",
                  style: subtitle2.copyWith(fontSize: 14)),
              const Gap(20),
              Container(
                  padding:
                      const EdgeInsets.symmetric(horizontal: 12, vertical: 16),
                  decoration: BoxDecoration(
                      boxShadow: const [
                        BoxShadow(
                            color: Color(0xFFEFEFEF),
                            spreadRadius: 2,
                            blurRadius: 16)
                      ],
                      color: Colors.white,
                      borderRadius: BorderRadius.circular(12)),
                  child: const Column(
                    children: [
                      ItemView(
                        title: "Super Fast ⚡️",
                        subText: "N15 per transaction on BankBox",
                      ),
                      Divider(
                        height: 20,
                      ),
                      ItemView(
                        title: "Fast",
                        subText: "N20 per transaction on BankBox",
                      ),
                    ],
                  )),
              const Gap(32),
              GestureDetector(
                onTap: () {
                  showRavenPayBottomSheet(context,
                      child: const NetworkStatusSheet());
                },
                child: Container(
                    padding: const EdgeInsets.symmetric(
                        horizontal: 16, vertical: 20),
                    decoration: BoxDecoration(
                        boxShadow: const [
                          BoxShadow(
                              color: Color(0xFFEFEFEF),
                              spreadRadius: 2,
                              blurRadius: 16)
                        ],
                        color: Colors.white,
                        borderRadius: BorderRadius.circular(12)),
                    child: Row(
                      children: [
                        Image.asset(loadAsset("network_stability.png"),
                            color: pluginConfig.theme!.primaryColor,
                            height: 20),
                        const Gap(12),
                        Expanded(
                          child: Text(
                            "View Network Status",
                            style: subtitle.copyWith(
                                color: pluginConfig.theme!.primaryColor),
                          ),
                        ),
                        const Icon(Icons.arrow_forward_ios, size: 12)
                      ],
                    )),
              )
            ])));
  }
}

class ItemView extends StatelessWidget {
  final String title;
  final String subText;
  const ItemView({super.key, required this.title, required this.subText});

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        SizedBox(
            width: 24,
            child: Radio(
                fillColor:
                    MaterialStateProperty.all(Colors.grey.withOpacity(0.4)),
                value: 1,
                groupValue: 0,
                onChanged: (val) {})),
        const Gap(8),
        Expanded(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(title, style: headling1.copyWith(fontSize: 16)),
              const Gap(2),
              Text(
                subText,
                style: subtitle2.copyWith(fontSize: 14),
              )
            ],
          ),
        )
      ],
    );
  }
}
